==> nmail-php-patch-2.3.0-to-2.3.1.tgz: nmail/mail_read.php <==
<?
require_once('include/global.php');
require_once("include/mail_lib.php");
require_once('conf.inc.php');


// check
	if (!$_GET['mb_id'] || !$_GET['mf_no'] )
		msg('ùٸ URL Ͽ ֽʽÿ');


// set
	$CFG['TITLE'] = '<b>б</b> >> <b>'.get_mb_name($_GET['mb_id']).'</b>';

	if ($_GET['back_url'])
	{
		cut_qs('back_url');
	} else
	{
		$_GET['back_url'] = 'mail_list.php?'.get_qs('mf_no');
	}	// if()


// data
	// db - select
	$DEBUG['db_select']['start'] = getmicrotime();
		$sql = "
			SELECT
				mf_no, mf_from, mf_reply_to, mf_sender, mf_to, mf_cc, mf_bcc, mf_importance, mf_subject, mf_body, mf_content_type, mf_charset, mf_arrival_date, mf_send_date, mf_filename, mf_filesize, mf_attach_names, mf_is_read, mf_is_read_date, mf_is_reply, mf_is_reply_date, mf_is_forward, mf_is_forward_date,  mf_send_ip , mf_spam_point , mf_is_userauth, mfext1
			FROM
				".$AUTH[auth_m_mf_table]."
			WHERE
				mf_no='" . $_GET['mf_no'] . "'
				AND m_no='" . $AUTH['auth_m_no'] . "'
				AND mb_id='" . $_GET['mb_id'] . "'
			";
		$row = db_get_row($sql);
		if (!$row)
		{
			msg(" ʴ Դϴ.\\n\\n̹ Ǿų ٸ  Ű  ֽϴ.", 0);
			movepage($_GET['back_url']);
		}	// if()
	$DEBUG['db_select']['exec'] += getmicrotime() - $DEBUG['db_select']['start'];

	// ش     ƿ迡 Ȱ ؼ ȭ .
	$mf_dir = get_mail_dir().'/'.get_mb_dir($_GET['mb_id']).'/';

	// [2005-12-03]    ۹̼ǹ̹Ƿ ȭ .
	if (!is_writable($mf_dir))
	{
		// [2006-10-23]   
		#error("  丮 ۹̼  ֽϴ.\n=> " . $mf_dir, 'FILE', false);
		error("  丮 ۹̼  ֽϴ.\n=> " . $mf_dir . "\n
  ó ߻ñ⿡  ٸϴ.

1.  ġϰ ٷ  ߻ .
	Apache   httpd.conf     Ȯغñ ٶϴ.
	Ȥ Group  #-1 ó   ʾƼ  ߻ϴ 쵵 ֽϴ.
	ex)
		/usr/local/apache/conf/httpd.conf
			User nobody
			Group #-1
			=>
			User nobody
			Group nobody

2.  ϴ  ڱ ߻ .
	ϵŸ  丮 , ۹̼     Ǿ ɼ ϴ.
	  Ʒó root ۹̼ ũƮ Ͻø ذ˴ϴ.
	ex)
		su
		cd ".dirname($G_SYS[PAGE_ROOT])."/tools/
		./perm_change.sh
", 'FILE', false);
	} else if ($row['mf_filename'] && !file_exists($mf_dir.$row['mf_filename']))
	{
		$sql = "
			DELETE
			FROM
				".$AUTH[auth_m_mf_table]."
			WHERE
				mf_no='" . $_GET['mf_no'] . "'
				AND m_no='" . $AUTH['auth_m_no'] . "'
				AND mb_id='" . $_GET['mb_id'] . "'
			";
		db_query($sql);
		msg(" ʴ Դϴ.\\n\\nƿ Ŭ̾Ʈ POP3 񽺸   \\n\\n[ ޽ 纻 ]ɼ üũ ʾ Ǿ ɼ ϴ.", 0);
		movepage($_GET['back_url']);
	}	// if()

	// db - mail index rebuild
		if ($_GET['mf_rebuild'])
		{
			mail_db_rebuild($AUTH['auth_m_mf_table'], $mf_dir.$row['mf_filename'], $_GET['mf_no'], $AUTH['auth_m_no']);
			movepage($_SERVER['PHP_SELF'].'?'.get_qs('mf_rebuild'));
		}	// if()

	// db - ǥ
		if ($row['mf_is_read'] == 'N')
		{
			$now = date('Y-m-d H:i:s');
			$sql = "
				UPDATE
					".$AUTH[auth_m_mf_table]."
				SET
					mf_is_read = 'Y',
					mf_is_read_date = '".$now."'
				WHERE
					mf_no='" . $_GET['mf_no'] . "'
					AND m_no='" . $AUTH['auth_m_no'] . "'
					AND mb_id='" . $_GET['mb_id'] . "'
				";
			db_query($sql);
		}	// if()

	// process data
		$mf = array();
		$mf = $row;

		$mf['mf_subject'] = (trim($row['mf_subject']) == NULL) ? "____" : htmlspecialchars_fix($row['mf_subject']);
		// [2005-07-12] ¥  ¥ .
		#$mf['mf_send_date'] = ($row['mf_send_date'] != '0000-00-00 00:00:00') ? $row['mf_send_date'] : $row['mf_send_date_str'];
		$mf['mf_send_date'] = ($row['mf_send_date'] != '0000-00-00 00:00:00') ? $row['mf_send_date'] : $row['mf_arrival_date'];
		$_from = mime_address_parse($row['mf_from']);
		// [2007-07-11] UTF-8  ѱ  ޵ǵ ó.
		//$mf['mf_from_name'] = htmlspecialchars_fix(addslashes($_from['display']));
		$mf['mf_from_name'] = urlencode(urlencode(base64_encode(htmlspecialchars_fix(addslashes($_from['display'])))));
		$mf['mf_from_email'] = htmlspecialchars_fix(addslashes($_from['address']));
		$mf['mf_from'] = address_view($row['mf_from']);
		$mf['mf_to'] = address_view($row['mf_to']);
		$_to = mime_address_parse($row['mf_to']);
		// [2007-07-11] UTF-8  ѱ  ޵ǵ ó.
		//$mf['mf_to_name'] = htmlspecialchars_fix(addslashes($_to['display']));
		$mf['mf_to_name'] = urlencode(urlencode(base64_encode(htmlspecialchars_fix(addslashes($_to['display'])))));
		$mf['mf_to_email'] = htmlspecialchars_fix(addslashes($_to['address']));
		$mf['mf_cc'] = address_view($row['mf_cc']);
		$mf['mf_bcc'] = address_view($row['mf_bcc']);
		$mf['mf_reply-to'] = address_view($row['mf_reply_to']);
		$mf['mf_sender'] = address_view($row['mf_sender']);
		$mf['is_attachment'] = ($row['mf_attach_names'] != NULL) ? true : false;
		$mf['mf_attach_names'] = attach_names_toarray($row['mf_attach_names']);
		if ($row['mf_content_type'] == 'H')
		{
			$mf['mf_body'] = set_mailbody_html($row['mf_body'], $_GET['mb_id']);
		} else
		{
			$mf['mf_body'] = auto_link(nl2br(htmlspecialchars_fix($row['mf_body'])));
		}	// if()

	// [2006-09-29]÷ ̹   Ʒ ٷ ֵ .
		for ($i=0; $i<sizeof($mf['mf_attach_names']['name']); $i++)
		{
			if (preg_match('/\.(jpg|jpeg|gif|png)$/i', $mf['mf_attach_names']['name'][$i]))
			{
				$mf['mf_body'] .= '<div style="padding:10px 0px 10px 10px"><img id=mf_attach_img_'.$i.' src="'.$nmpath.'/mail_attach_down.php?'.get_qs().'&mf_an_name='.$mf['mf_attach_names']['name_url'][$i].'&mf_an_struct='.$mf['mf_attach_names']['struct'][$i].'" alt="÷ : '.htmlspecialchars_fix($mf['mf_attach_names']['name'][$i].' ('.$mf['mf_attach_names']['size_human'][$i].')').'" style="position: absolute; visibility: hidden" onLoad="JavaScript:onload_mf_attach_img_'.$i.'();"></div>
					<script>
						function onload_mf_attach_img_'.$i.'()
						{
							var obj_mf_attach_img_'.$i.' = new Image();
							obj_mf_attach_img_'.$i.'.src = document.all.mf_attach_img_'.$i.'.src;
							var imgMaxWidth = document.body.clientWidth - 330;
							if (obj_mf_attach_img_'.$i.' && obj_mf_attach_img_'.$i.'.width > imgMaxWidth)
								document.all.mf_attach_img_'.$i.'.width = imgMaxWidth;
							document.all.mf_attach_img_'.$i.'.style.position = "static";
							document.all.mf_attach_img_'.$i.'.style.visibility = "visible";
						}	// function()
					</script>';
			}	// if()
		}	// for()

	// Ϲڽ
		$mail_box = get_mail_box();
		$_mail_box = db_rows_fieldtokey($mail_box);
		$select_mail_box = select_list_value($_GET['mb_id'], $_mail_box['mb_name'], $_mail_box['mb_id'], NULL, 0, 1);


// [2006-06-13] ,  
	$DEBUG['db_prev']['start'] = getmicrotime();
	// [2006-09-14] Oracle Hint
	$q_hint = '';
	$q_stopkey = '';
	if ($G_SYS[DB] == 'oracle')
	{
		$q_stopkey = " AND ROWNUM <= 1 ";
		$q_hint = "/*+ ORDERED index_desc (".$AUTH['auth_m_mf_table']." MF_".$AUTH['auth_d_no']."_".$AUTH['auth_m_mail_file_group']."_MF_ARRIVAL_DATE) */";
	}	// if()
	$sql = "
		SELECT
			$q_hint
			mf_no
		FROM
			".$AUTH[auth_m_mf_table]."
		WHERE
			mf_arrival_date >= '" . $row['mf_arrival_date'] . "'
			AND m_no='" . $AUTH['auth_m_no'] . "'
			AND mb_id='" . $_GET['mb_id'] . "'
			AND mf_no != '" . $_GET['mf_no'] . "'
			AND (
				mf_arrival_date != '" . $row['mf_arrival_date'] . "'
				OR 
					( mf_arrival_date = '" . $row['mf_arrival_date'] . "'
						AND mf_no < '" . $_GET['mf_no'] . "'
					)
				)
			$q_stopkey
		ORDER BY
			mf_arrival_date, mf_no DESC
		";
	$rows = db_get_rows($sql, 0, 1);
	$mf_no_prev = ($rows[0]['mf_no']) ? $rows[0]['mf_no'] : 0;
	$DEBUG['db_prev']['exec'] += getmicrotime() - $DEBUG['db_prev']['start'];

	$DEBUG['db_next']['start'] = getmicrotime();
	// [2006-09-14] Oracle Hint
	$q_hint = '';
	$q_stopkey = '';
	if ($G_SYS[DB] == 'oracle')
	{
		$q_stopkey = " AND ROWNUM <= 1 ";
		$q_hint = "/*+ ORDERED index_asc (".$AUTH['auth_m_mf_table']." MF_".$AUTH['auth_d_no']."_".$AUTH['auth_m_mail_file_group']."_MF_ARRIVAL_DATE) */";
	}	// if()
	$sql = "
		SELECT
			$q_hint
			mf_no
		FROM
			".$AUTH[auth_m_mf_table]."
		WHERE
			mf_arrival_date <= '" . $row['mf_arrival_date'] . "'
			AND m_no='" . $AUTH['auth_m_no'] . "'
			AND mb_id='" . $_GET['mb_id'] . "'
			AND mf_no != '" . $_GET['mf_no'] . "'
			AND mf_no != '" . $mf_no_prev . "'
			$q_stopkey
		ORDER BY
			mf_arrival_date DESC, mf_no
		";
	$rows = db_get_rows($sql, 0, 1);
	$mf_no_next = ($rows[0]['mf_no']) ? $rows[0]['mf_no'] : 0;
	$DEBUG['db_next']['exec'] += getmicrotime() - $DEBUG['db_next']['start'];


// skin view
	nskinset('webmail', 'mail_read.html');
	include($NSKIN['view_layout']);


require_once('include/global_end.php');
?>

==> nmail-php-patch-2.3.1-to-2.4.0.tgz: nmail/mail_read.php <==
<?
require_once('include/global.php');
require_once("include/mail_lib.php");
require_once('conf.inc.php');


// check
	if (!$_GET['mb_id'] || !$_GET['mf_no'] )
		msg('ùٸ URL Ͽ ֽʽÿ');


// set
	$CFG['TITLE'] = '<b>б</b> >> <b>'.get_mb_name($_GET['mb_id']).'</b>';

	if ($_GET['back_url'])
	{
		cut_qs('back_url');
	} else
	{
		$_GET['back_url'] = 'mail_list.php?'.get_qs('mf_no');
	}	// if()


// data
	// db - select
	$DEBUG['db_select']['start'] = getmicrotime();
		$sql = "
			SELECT
				mf_no, mf_from, mf_reply_to, mf_sender, mf_to, mf_cc, mf_bcc, mf_importance, mf_subject, mf_body, mf_content_type, mf_charset, mf_arrival_date, mf_send_date, mf_filename, mf_filesize, mf_attach_names, mf_is_read, mf_is_read_date, mf_is_reply, mf_is_reply_date, mf_is_forward, mf_is_forward_date,  mf_send_ip , mf_spam_point , mf_is_userauth, mfext1
			FROM
				".$AUTH[auth_m_mf_table]."
			WHERE
				mf_no='" . $_GET['mf_no'] . "'
				AND m_no='" . $AUTH['auth_m_no'] . "'
				AND mb_id='" . $_GET['mb_id'] . "'
			";
		$row = db_get_row($sql);
		if (!$row)
		{
			msg(" ʴ Դϴ.\\n\\n̹ Ǿų ٸ  Ű  ֽϴ.", 0);
			movepage($_GET['back_url']);
		}	// if()
	$DEBUG['db_select']['exec'] += getmicrotime() - $DEBUG['db_select']['start'];

	// ش     ƿ迡 Ȱ ؼ ȭ .
	$mf_dir = get_mail_dir().'/'.get_mb_dir($_GET['mb_id']).'/';

	// [2005-12-03]    ۹̼ǹ̹Ƿ ȭ .
	if (!is_writable($mf_dir))
	{
		// [2006-10-23]   
		#error("  丮 ۹̼  ֽϴ.\n=> " . $mf_dir, 'FILE', false);
		error("  丮 ۹̼  ֽϴ.\n=> " . $mf_dir . "\n
  ó ߻ñ⿡  ٸϴ.

1.  ġϰ ٷ  ߻ .
	Apache   httpd.conf     Ȯغñ ٶϴ.
	Ȥ Group  #-1 ó   ʾƼ  ߻ϴ 쵵 ֽϴ.
	ex)
		/usr/local/apache/conf/httpd.conf
			User nobody
			Group #-1
			=>
			User nobody
			Group nobody

2.  ϴ  ڱ ߻ .
	ϵŸ  丮 , ۹̼     Ǿ ɼ ϴ.
	  Ʒó root ۹̼ ũƮ Ͻø ذ˴ϴ.
	ex)
		su
		cd ".dirname($G_SYS[PAGE_ROOT])."/tools/
		./perm_change.sh
", 'FILE', false);
	} else if ($row['mf_filename'] && !file_exists($mf_dir.$row['mf_filename']))
	{
		$sql = "
			DELETE
			FROM
				".$AUTH[auth_m_mf_table]."
			WHERE
				mf_no='" . $_GET['mf_no'] . "'
				AND m_no='" . $AUTH['auth_m_no'] . "'
				AND mb_id='" . $_GET['mb_id'] . "'
			";
		db_query($sql);
		msg(" ʴ Դϴ.\\n\\nƿ Ŭ̾Ʈ POP3 񽺸   \\n\\n[ ޽ 纻 ]ɼ üũ ʾ Ǿ ɼ ϴ.", 0);
		movepage($_GET['back_url']);
	}	// if()

	// db - mail index rebuild
		if ($_GET['mf_rebuild'])
		{
			mail_db_rebuild($AUTH['auth_m_mf_table'], $mf_dir.$row['mf_filename'], $_GET['mf_no'], $AUTH['auth_m_no']);
			movepage($_SERVER['PHP_SELF'].'?'.get_qs('mf_rebuild'));
		}	// if()

	// db - ǥ
		if ($row['mf_is_read'] == 'N')
		{
			$now = date('Y-m-d H:i:s');
			$sql = "
				UPDATE
					".$AUTH[auth_m_mf_table]."
				SET
					mf_is_read = 'Y',
					mf_is_read_date = '".$now."'
				WHERE
					mf_no='" . $_GET['mf_no'] . "'
					AND m_no='" . $AUTH['auth_m_no'] . "'
					AND mb_id='" . $_GET['mb_id'] . "'
				";
			db_query($sql);
		}	// if()

	// process data
		$mf = array();
		$mf = $row;

		$mf['mf_subject'] = (trim($row['mf_subject']) == NULL) ? "____" : htmlspecialchars_fix($row['mf_subject']);
		// [2005-07-12] ¥  ¥ .
		#$mf['mf_send_date'] = ($row['mf_send_date'] != '0000-00-00 00:00:00') ? $row['mf_send_date'] : $row['mf_send_date_str'];
		$mf['mf_send_date'] = ($row['mf_send_date'] != '0000-00-00 00:00:00') ? $row['mf_send_date'] : $row['mf_arrival_date'];
		$_from = mime_address_parse($row['mf_from']);
		// [2007-07-11] UTF-8  ѱ  ޵ǵ ó.
		//$mf['mf_from_name'] = htmlspecialchars_fix(addslashes($_from['display']));
		$mf['mf_from_name'] = urlencode(urlencode(base64_encode(htmlspecialchars_fix(addslashes($_from['display'])))));
		$mf['mf_from_email'] = htmlspecialchars_fix(addslashes($_from['address']));
		$mf['mf_from'] = address_view($row['mf_from']);
		$mf['mf_to'] = address_view($row['mf_to']);
		$_to = mime_address_parse($row['mf_to']);
		// [2007-07-11] UTF-8  ѱ  ޵ǵ ó.
		//$mf['mf_to_name'] = htmlspecialchars_fix(addslashes($_to['display']));
		$mf['mf_to_name'] = urlencode(urlencode(base64_encode(htmlspecialchars_fix(addslashes($_to['display'])))));
		$mf['mf_to_email'] = htmlspecialchars_fix(addslashes($_to['address']));
		$mf['mf_cc'] = address_view($row['mf_cc']);
		$mf['mf_bcc'] = address_view($row['mf_bcc']);
		$mf['mf_reply-to'] = address_view($row['mf_reply_to']);
		$mf['mf_sender'] = address_view($row['mf_sender']);
		$mf['is_attachment'] = ($row['mf_attach_names'] != NULL) ? true : false;
		$mf['mf_attach_names'] = attach_names_toarray($row['mf_attach_names']);
		if ($row['mf_content_type'] == 'H')
		{
			$mf['mf_body'] = set_mailbody_html($row['mf_body'], $_GET['mb_id']);
		} else
		{
			$mf['mf_body'] = auto_link(nl2br(htmlspecialchars_fix($row['mf_body'])));
		}	// if()

	// [2006-09-29]÷ ̹   Ʒ ٷ ֵ .
		for ($i=0; $i<sizeof($mf['mf_attach_names']['name']); $i++)
		{
			if (preg_match('/\.(jpg|jpeg|gif|png)$/i', $mf['mf_attach_names']['name'][$i]))
			{
				$mf['mf_body'] .= '<div style="padding:10px 0px 10px 10px"><img id=mf_attach_img_'.$i.' src="'.$nmpath.'/mail_attach_down.php?'.get_qs().'&mf_an_struct='.$mf['mf_attach_names']['struct'][$i].'" alt="÷ : '.htmlspecialchars_fix($mf['mf_attach_names']['name'][$i].' ('.$mf['mf_attach_names']['size_human'][$i].')').'" style="position: absolute; visibility: hidden" onLoad="JavaScript:onload_mf_attach_img_'.$i.'();"></div>
					<script>
						function onload_mf_attach_img_'.$i.'()
						{
							var obj_mf_attach_img_'.$i.' = new Image();
							obj_mf_attach_img_'.$i.'.src = document.all.mf_attach_img_'.$i.'.src;
							var imgMaxWidth = document.body.clientWidth - 330;
							if (obj_mf_attach_img_'.$i.' && obj_mf_attach_img_'.$i.'.width > imgMaxWidth)
								document.all.mf_attach_img_'.$i.'.width = imgMaxWidth;
							document.all.mf_attach_img_'.$i.'.style.position = "static";
							document.all.mf_attach_img_'.$i.'.style.visibility = "visible";
						}	// function()
					</script>';
			}	// if()
		}	// for()

	// Ϲڽ
		$mail_box = get_mail_box();
		$_mail_box = db_rows_fieldtokey($mail_box);
		$select_mail_box = select_list_value($_GET['mb_id'], $_mail_box['mb_name'], $_mail_box['mb_id'], NULL, 0, 1);


// [2006-06-13] ,  
	$DEBUG['db_prev']['start'] = getmicrotime();
	// [2006-09-14] Oracle Hint
	$q_hint = '';
	$q_stopkey = '';
	if ($G_SYS[DB] == 'oracle')
	{
		$q_stopkey = " AND ROWNUM <= 1 ";
		$q_hint = "/*+ ORDERED index_desc (".$AUTH['auth_m_mf_table']." MF_".$AUTH['auth_d_no']."_".$AUTH['auth_m_mail_file_group']."_MF_ARRIVAL_DATE) */";
	}	// if()
	$sql = "
		SELECT
			$q_hint
			mf_no
		FROM
			".$AUTH[auth_m_mf_table]."
		WHERE
			mf_arrival_date >= '" . $row['mf_arrival_date'] . "'
			AND m_no='" . $AUTH['auth_m_no'] . "'
			AND mb_id='" . $_GET['mb_id'] . "'
			AND mf_no != '" . $_GET['mf_no'] . "'
			AND (
				mf_arrival_date != '" . $row['mf_arrival_date'] . "'
				OR 
					( mf_arrival_date = '" . $row['mf_arrival_date'] . "'
						AND mf_no < '" . $_GET['mf_no'] . "'
					)
				)
			$q_stopkey
		ORDER BY
			mf_arrival_date, mf_no DESC
		";
	$rows = db_get_rows($sql, 0, 1);
	$mf_no_prev = ($rows[0]['mf_no']) ? $rows[0]['mf_no'] : 0;
	$DEBUG['db_prev']['exec'] += getmicrotime() - $DEBUG['db_prev']['start'];

	$DEBUG['db_next']['start'] = getmicrotime();
	// [2006-09-14] Oracle Hint
	$q_hint = '';
	$q_stopkey = '';
	if ($G_SYS[DB] == 'oracle')
	{
		$q_stopkey = " AND ROWNUM <= 1 ";
		$q_hint = "/*+ ORDERED index_asc (".$AUTH['auth_m_mf_table']." MF_".$AUTH['auth_d_no']."_".$AUTH['auth_m_mail_file_group']."_MF_ARRIVAL_DATE) */";
	}	// if()
	$sql = "
		SELECT
			$q_hint
			mf_no
		FROM
			".$AUTH[auth_m_mf_table]."
		WHERE
			mf_arrival_date <= '" . $row['mf_arrival_date'] . "'
			AND m_no='" . $AUTH['auth_m_no'] . "'
			AND mb_id='" . $_GET['mb_id'] . "'
			AND mf_no != '" . $_GET['mf_no'] . "'
			AND mf_no != '" . $mf_no_prev . "'
			$q_stopkey
		ORDER BY
			mf_arrival_date DESC, mf_no
		";
	$rows = db_get_rows($sql, 0, 1);
	$mf_no_next = ($rows[0]['mf_no']) ? $rows[0]['mf_no'] : 0;
	$DEBUG['db_next']['exec'] += getmicrotime() - $DEBUG['db_next']['start'];


// skin view
	nskinset('webmail', 'mail_read.html');
	include($NSKIN['view_layout']);


require_once('include/global_end.php');
?>
